﻿using System.Threading;
using System.Threading.Tasks;

namespace HeuristicLab.PluginInfrastructure {

  /// <summary>
  /// Interface for all runner implementations.
  /// </summary>
  public interface IRunnerHost {
    /// <summary>
    /// The runner state.
    /// </summary>
    RunnerState State { get; }

    /// <summary>
    /// Set this to true, if console output should be disabled.
    /// </summary>
    bool QuietMode { get; set; }

    /// <summary>
    /// Method to run the runner. This method is blocking.
    /// </summary>
    /// <param name="runner">A instance of an IRunner.</param>
    void Run(IRunner runner);

    /// <summary>
    /// Method to run the runner async. A CencellationToken can be specified.
    /// </summary>
    /// <param name="runner">A instance of an IRunner</param>
    /// <param name="token">The CancellationToken obtained from an CancellationTokenSource.</param>
    /// <returns>The task in which the process runs.</returns>
    Task RunAsync(IRunner runner, CancellationToken? token = null);

    /// <summary>
    /// Method to send messages to the runner, which runs in child process.
    /// </summary>
    /// <param name="runnerMessage">A object from a derived class of RunnerMessage.</param>
    void Send(RunnerMessage runnerMessage);
  }
}
